ebs-modbus
==========

.. image:: https://img.shields.io/pypi/v/ebs-modbus.svg
    :target: https://pypi.python.org/pypi/ebs-modbus
    :alt: Latest PyPI version

Python host interface to EBS modbus devices

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`ebs-modbus` was written by `Chintalagiri Shashank <shashank.chintalagiri@gmail.com>`_.
